@@ -10,7 +10,7 @@ class Command(BaseCommand):
     
     def handle(self, *args, **options):
         sys.stdout.write("\nResolving app groups")
-        app_list = [app_name.lower() for app_name in settings.DEVELOPER_INSTALLED_APPS]
+        app_list = [app_name.lower() for app_name in settings.ACCESS_CONTROLLED_INSTALLED_APPS]
         for app_name in app_list:
             created = Group.objects.get_or_create(name=app_name)
             sys.stdout.write(f"\n{app_name}, new={created}")
